Class: Google::Apis::WebriskV1::GoogleLongrunningOperation
- Inherits:
-
Object
- Object
- Google::Apis::WebriskV1::GoogleLongrunningOperation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/webrisk_v1/classes.rb,
lib/google/apis/webrisk_v1/representations.rb,
lib/google/apis/webrisk_v1/representations.rb
Overview
This resource represents a long-running operation that is the result of a network API call.
Instance Attribute Summary collapse
-
#done ⇒ Boolean
(also: #done?)
If the value is
false, it means the operation is still in progress. -
#error ⇒ Google::Apis::WebriskV1::GoogleRpcStatus
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#metadata ⇒ Hash<String,Object>
Contains a
SubmitUriMetadataobject. -
#name ⇒ String
Matches the
/v1/project-name/operations/operation-id`` pattern. -
#response ⇒ Hash<String,Object>
The normal, successful response of the operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GoogleLongrunningOperation
constructor
A new instance of GoogleLongrunningOperation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GoogleLongrunningOperation
Returns a new instance of GoogleLongrunningOperation.
468 469 470 |
# File 'lib/google/apis/webrisk_v1/classes.rb', line 468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#done ⇒ Boolean Also known as: done?
If the value is false, it means the operation is still in progress. If true
, the operation is completed, and either error or response is available.
Corresponds to the JSON property done
434 435 436 |
# File 'lib/google/apis/webrisk_v1/classes.rb', line 434 def done @done end |
#error ⇒ Google::Apis::WebriskV1::GoogleRpcStatus
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
445 446 447 |
# File 'lib/google/apis/webrisk_v1/classes.rb', line 445 def error @error end |
#metadata ⇒ Hash<String,Object>
Contains a SubmitUriMetadata object.
Corresponds to the JSON property metadata
450 451 452 |
# File 'lib/google/apis/webrisk_v1/classes.rb', line 450 def @metadata end |
#name ⇒ String
Matches the /v1/project-name/operations/operation-id`pattern.
Corresponds to the JSON propertyname`
455 456 457 |
# File 'lib/google/apis/webrisk_v1/classes.rb', line 455 def name @name end |
#response ⇒ Hash<String,Object>
The normal, successful response of the operation. If the original method
returns no data on success, such as Delete, the response is google.protobuf.
Empty. If the original method is standard Get/Create/Update, the
response should be the resource. For other methods, the response should have
the type XxxResponse, where Xxx is the original method name. For example,
if the original method name is TakeSnapshot(), the inferred response type is
TakeSnapshotResponse.
Corresponds to the JSON property response
466 467 468 |
# File 'lib/google/apis/webrisk_v1/classes.rb', line 466 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
473 474 475 476 477 478 479 |
# File 'lib/google/apis/webrisk_v1/classes.rb', line 473 def update!(**args) @done = args[:done] if args.key?(:done) @error = args[:error] if args.key?(:error) @metadata = args[:metadata] if args.key?(:metadata) @name = args[:name] if args.key?(:name) @response = args[:response] if args.key?(:response) end |